# Access SFTP Server
This project contains the basic files to up- and download files from a SFTP Server.

For further information contact [Valentin Baier](mailto:baier@orcacapital.de?subject=Google%20Workspace%20Account).

## Installation
The installation can be achieved by using ``pip``:

``python -m pip install access_sftp_server``

## Run via Shell
To run the application via shell you need to either execute:

``python -m cibc_sftp_server.upload_files`` or
``python -m cibc_sftp_server.download_files``

## Usage
The package can be executed from any computer having the required credentials to the server.

## License
This project is licensed by a MIT License.

## Project status
The current released version is 0.0.9.
